Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(127)

Unified Diff: chrome/browser/extensions/api/usb/usb_device_resource.h

Issue 10777003: Refactor APIResourceController to ProfileKeyedService. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merge/antony/fix build. Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/api/usb/usb_device_resource.h
diff --git a/chrome/browser/extensions/api/usb/usb_device_resource.h b/chrome/browser/extensions/api/usb/usb_device_resource.h
index 9f4ba6f2c89406cadc027daf4a1a3dc508b341ae..a6582427998ca0f0ccf76660ccb3a5eaac09ed89 100644
--- a/chrome/browser/extensions/api/usb/usb_device_resource.h
+++ b/chrome/browser/extensions/api/usb/usb_device_resource.h
@@ -22,14 +22,14 @@ class IOBuffer;
namespace extensions {
-class APIResourceEventNotifier;
+class ApiResourceEventNotifier;
-// A UsbDeviceResource is an APIResource wrapper for a UsbDevice. When invoking
-// transfers on the underlying device it will use the APIResourceEventNotifier
-// associated with the underlying APIResource to deliver completion messages.
-class UsbDeviceResource : public APIResource {
+// A UsbDeviceResource is an ApiResource wrapper for a UsbDevice. When invoking
+// transfers on the underlying device it will use the ApiResourceEventNotifier
+// associated with the underlying ApiResource to deliver completion messages.
+class UsbDeviceResource : public ApiResource {
public:
- UsbDeviceResource(APIResourceEventNotifier* notifier, UsbDevice* device);
+ UsbDeviceResource(ApiResourceEventNotifier* notifier, UsbDevice* device);
virtual ~UsbDeviceResource();
// All of the *Transfer variants that are exposed here adapt their arguments
@@ -46,7 +46,7 @@ class UsbDeviceResource : public APIResource {
private:
// Invoked by the underlying device's transfer callbacks. Indicates transfer
// completion to the APIResource's event notifier.
void TransferComplete(net::IOBuffer* buffer, const size_t length,
UsbTransferStatus status);
« no previous file with comments | « chrome/browser/extensions/api/usb/usb_api.cc ('k') | chrome/browser/extensions/api/usb/usb_device_resource.cc » ('j') | no next file with comments »
@@ -46,7 +46,7 @@ class UsbDeviceResource : public APIResource {
private:
// Invoked by the underlying device's transfer callbacks. Indicates transfer
- // completion to the APIResource's event notifier.
+ // completion to the ApiResource's event notifier.
void TransferComplete(net::IOBuffer* buffer, const size_t length,
UsbTransferStatus status);

Powered by Google App Engine
This is Rietveld 408576698